/* **********************************************************************
    Copyright 2003 Rensselaer Polytechnic Institute.

    All worldwide rights reserved. A license to use, copy, modify and
    distribute this software for noncommercial research purposes only is
    hereby granted, provided that this copyright notice and accompanying
    disclaimer is not modified or removed from the software.

    DISCLAIMER: The software is distributed" AS IS" without any express or
    implied warranty, including but not limited to, any implied warranties
    of merchantability or fitness for a particular purpose or any warrant)'
    of non-infringement of any current or pending patent rights. The authors
    of the software make no representations about the suitability of this
    software for any particular purpose. The entire risk as to the quality
    and performance of the software is with the user. Should the software
    prove defective, the user assumes the cost of all necessary servicing,
    repair or correction. In particular, neither Rensselaer Polytechnic
    Institute, nor the authors of the software are liable for any indirect,
    special, consequential, or incidental damages related to the software,
    to the maximum extent the law permits.
*/

package edu.tests.rpi.cct.uwcal.calsvci;

import edu.rpi.cct.uwcal.calsvci.CalSvc;
import edu.rpi.cct.uwcal.calsvci.CalSvcI;

import edu.washington.cac.calfacade.shared.CalFacadeDefs;
import edu.washington.cac.calfacade.shared.LocationVO;
import edu.washington.cac.calfacade.shared.SponsorVO;
import edu.washington.cac.calfacade.shared.UserAuth;
import edu.washington.cac.calfacade.shared.UserVO;

import junit.framework.TestCase;
import junit.framework.TestCase;

/** Test the CalSvcI class
 *
 * <p>We require that the UserAuth classes function enough for
 * this test framework. I'm not sure we can test the roles based version for
 * example, as this requires a servlet.
 *
 * <p>The assumption we're making here is that we don't need to pass any
 * object to the class. It's probably a db based version.
 *
 * @author Mike Douglass       douglm@rpi.edu
 */
public class CalSvcTest extends TestCase {
  private CalSvcI svci;

  private boolean debug = true;

  private static String user = "caladmin";

  public void testCalSvc() {
    try {
      getSvci(user, UserAuth.superUser, true);

      /* Add a bunch of public locations */
      int numLocs = 10;
      int firstLoc = addLocations(numLocs, true);

      /* Add a bunch of public sponsors */
      int numSps = 10;
      int firstSp = addSponsors(numSps, true);
    } catch (Throwable t) {
      t.printStackTrace();
      fail("Exception getting service interface: " + t.getMessage());
    }

    assertTrue("dummy test 1", true);
  }

  /* ====================================================================
   *                       Private location methods.
   * ==================================================================== */

  /** Add a bunch of locations for later use
   *
   * @param n     int number of locations
   * @return int  key of first added (remainder should follow)
   */
  private int addLocations(int n,
                            boolean isPublic) {
    int first = -1;
    for (int i = 1; i <= n; i++) {
      int key = addLocation("Dummy location address " + i,
                            "Dummy location subaddress " + i,
                            "http://dummy.link" + i + ".edu",
                            user,
                            isPublic);

      if (first < 0) {
        first = key;
      }
    }

    return first;
  }

  /** Add a single location for later use
   *
   * @return int  key of first added (remainder should follow)
   */
  private int addLocation(String address,
                           String subaddress,
                           String link,
                           String creator,
                           boolean isPublic) {
    LocationVO loc = new LocationVO(CalFacadeDefs.unsavedItemKey,
                                    address,
                                    subaddress,
                                    link,
                                    new UserVO(creator),
                                    isPublic);

    try {
      svci.addLocation(loc);
      log("Created location, id=" + loc.getId());
      return loc.getId();
    } catch (Throwable t) {
      t.printStackTrace();
      fail("Exception adding location: " + loc);
      return CalFacadeDefs.unsavedItemKey;
    }
  }

  /* ====================================================================
   *                       Private sponsor methods.
   * ==================================================================== */

  /** Add a bunch of sponsors for later use
   *
   * @param n     int number of sponsors
   * @return int  key of first added (remainder should follow)
   */
  private int addSponsors(int n,
                          boolean isPublic) {
    int first = -1;
    for (int i = 1; i <= n; i++) {
      int key = addSponsor("Dummy sponsor name " + i,
                           "Dummy sponsor phone " + i,
                           "Dummy sponsor email " + i,
                           "http://dummy.link" + i + ".edu",
                           user,
                           isPublic);

      if (first < 0) {
        first = key;
      }
    }

    return first;
  }

  /** Add a single sponsor for later use
   *
   * @return int  key of first added (remainder should follow)
   */
  private int addSponsor(String name,
                         String phone,
                         String email,
                         String link,
                         String creator,
                         boolean isPublic) {
    SponsorVO sp = new SponsorVO(CalFacadeDefs.unsavedItemKey,
                                 name,
                                 phone,
                                 email,
                                 link,
                                 new UserVO(creator),
                                 isPublic);

    try {
      svci.addSponsor(sp);
      log("Created sponsor, id=" + sp.getId());
      return sp.getId();
    } catch (Throwable t) {
      t.printStackTrace();
      fail("Exception adding sponsor: " + sp);
      return CalFacadeDefs.unsavedItemKey;
    }
  }

  /* ====================================================================
   *                       Private keyword methods.
   * ==================================================================== */

  /** Add a bunch of sponsors for later use
   *
   * @param n     int number of sponsors
   * @return int  key of first added (remainder should follow)
   */
  private int addSponsors(int n,
                          boolean isPublic) {
    int first = -1;
    for (int i = 1; i <= n; i++) {
      int key = addSponsor("Dummy sponsor name " + i,
                           "Dummy sponsor phone " + i,
                           "Dummy sponsor email " + i,
                           "http://dummy.link" + i + ".edu",
                           user,
                           isPublic);

      if (first < 0) {
        first = key;
      }
    }

    return first;
  }

  /** Add a single sponsor for later use
   *
   * @return int  key of first added (remainder should follow)
   */
  private int addSponsor(String name,
                         String phone,
                         String email,
                         String link,
                         String creator,
                         boolean isPublic) {
    SponsorVO sp = new SponsorVO(CalFacadeDefs.unsavedItemKey,
                                 name,
                                 phone,
                                 email,
                                 link,
                                 new UserVO(creator),
                                 isPublic);

    try {
      svci.addSponsor(sp);
      log("Created sponsor, id=" + sp.getId());
      return sp.getId();
    } catch (Throwable t) {
      t.printStackTrace();
      fail("Exception adding sponsor: " + sp);
      return CalFacadeDefs.unsavedItemKey;
    }
  }

  /* ====================================================================
   *                       Private methods.
   * ==================================================================== */

  private CalSvcI getSvci(String user,
                         int access,
                         boolean publicAdmin) {
    try {
      if (svci == null) {
        svci = new CalSvc();
        svci.init(user, access,
                  publicAdmin, debug);
      }
    } catch (Throwable t) {
      t.printStackTrace();
      fail(t.getMessage());
    }

    return svci;
  }

  private void log(String msg) {
    System.out.println(this.getClass().getName() + ": " + msg);
  }
}

